@@ -1,6 +1,7 @@
 from .version import __version__
 import click
 from .commands.record import record
+from .commands.optimize import optimize
 from .commands.verify import verify
 
 
@@ -11,6 +12,7 @@ def main():
 
 
 main.add_command(record)
+main.add_command(optimize)
 main.add_command(verify)
 
 if __name__ == '__main__':
