@@ -1,6 +1,7 @@
 from .build import build
 from .commit import commit
 from .test import test
+from .session import session
 import click
 
 
@@ -12,3 +13,4 @@ def record():
 record.add_command(build)
 record.add_command(commit)
 record.add_command(test)
+record.add_command(session)
